@@ -20,8 +20,9 @@ from __future__ import absolute_import
 from __future__ import print_function
 
 import os
-
+import io
 import logging
+
 import click
 
 import zhmcclient
@@ -863,7 +864,7 @@ Help for usage related options of the partition list command:
             resource_filter.append(('cpc', cpc_name))
         mov_list, _ = get_metric_values(
             client, metric_group, resource_filter)
-        partition_metrics = dict()
+        partition_metrics = {}
         for mov in mov_list:
             assert isinstance(mov.resource, zhmcclient.Partition)
             p_name = mov.resource.name
@@ -1316,7 +1317,6 @@ def cmd_partition_dump(cmd_ctx, cpc_name, partition_name, **options):
 
     client = zhmcclient.Client(cmd_ctx.session)
     partition = find_partition(cmd_ctx, client, cpc_name, partition_name)
-    options = original_options(options)
 
     if storage_management_feature(partition):
         partition_dump_with_sm(cmd_ctx, partition, **options)
@@ -1339,7 +1339,8 @@ def partition_dump_with_sm(cmd_ctx, partition, **options):
         'volume': None,  # Handled in this function
         'timeout': None,  # Handled in this function
     }
-    dpi_parms = options_to_properties(options, dpi_name_map)
+    org_options = original_options(options)
+    dpi_parms = options_to_properties(org_options, dpi_name_map)
     volume_opt = options['volume']  # It is required
     timeout = options['timeout']  # It is optional but has a default
 
@@ -1375,8 +1376,8 @@ def partition_dump_without_sm(cmd_ctx, partition, **options):
         'volume': None,  # Handled in this function
         'timeout': None,  # Ignored
     }
-    options = original_options(options)
-    parameters = options_to_properties(options, name_map)
+    org_options = original_options(options)
+    parameters = options_to_properties(org_options, name_map)
     volume_opt = options['volume']  # It is required
 
     hba, wwpn, lun = parse_volume_without_sm(
@@ -1403,7 +1404,7 @@ def cmd_partition_mount_iso(cmd_ctx, cpc_name, partition_name, options):
 
     image_file = options['imagefile']
     _, image_name = os.path.split(image_file)
-    with open(image_file, 'rb') as image_fp:
+    with io.open(image_file, 'rb') as image_fp:
         partition.mount_iso_image(image_fp, image_name, options['imageinsfile'])
     if options['boot']:
         partition.update_properties({'boot-device': 'iso-image'})
