@@ -454,14 +454,14 @@ def cmd_storagegroup_update(cmd_ctx, stogrp_name, options):
         'email-to-address': None,
         'email-cc-address': None,
     }
-    options = original_options(options)
-    properties = options_to_properties(options, name_map)
+    org_options = original_options(options)
+    properties = options_to_properties(org_options, name_map)
 
-    email_to_addresses = options['email-to-address']
+    email_to_addresses = org_options['email-to-address']
     if email_to_addresses:
         properties['email-to-addresses'] = email_to_addresses
 
-    email_cc_addresses = options['email-cc-address']
+    email_cc_addresses = org_options['email-cc-address']
     if email_cc_addresses:
         properties['email-cc-addresses'] = email_cc_addresses
 
@@ -492,11 +492,11 @@ def cmd_storagegroup_delete(cmd_ctx, stogrp_name, options):
     client = zhmcclient.Client(cmd_ctx.session)
     stogrp = find_storagegroup(cmd_ctx, client, stogrp_name)
 
-    options = original_options(options)
+    org_options = original_options(options)
 
-    email_insert = options['email-insert']
-    email_to_addresses = options['email-to-address'] or None
-    email_cc_addresses = options['email-cc-address'] or None
+    email_insert = org_options['email-insert']
+    email_to_addresses = org_options['email-to-address'] or None
+    email_cc_addresses = org_options['email-cc-address'] or None
 
     try:
         stogrp.delete(email_to_addresses=email_to_addresses,
