@@ -325,6 +325,8 @@ class CmdContext(object):
         self.spinner.start()
         try:
             cmd()
+        except zhmcclient.Error as exc:
+            raise click_exception(exc, self.error_format)
         finally:
             self.spinner.stop()
             if self._session.time_stats_keeper.enabled:
@@ -570,7 +572,7 @@ def print_resources_as_table(
     remaining_prop_names = OrderedDict()  # key: property name, value: None
     resource_props_list = []
     for resource in resources:
-        resource_props = dict()
+        resource_props = {}
         if show_list:
             for name in show_list:
                 if additions and name in additions:
@@ -633,7 +635,7 @@ def dict_as_table(data, headers, table_format, show_list=None):
     if table_format == 'repr':
         ret_str = repr(data)
     else:
-        table = list()
+        table = []
         inner_format = INNER_TABLE_FORMAT.get(table_format, table_format)
         sorted_fields = sorted(data)
         for field in sorted_fields:
@@ -659,7 +661,7 @@ def list_as_table(data, table_format):
     if table_format == 'repr':
         ret_str = repr(data)
     else:
-        table = list()
+        table = []
         inner_format = INNER_TABLE_FORMAT.get(table_format, table_format)
         for value in data:
             value = value_as_table(value, inner_format)
@@ -759,7 +761,7 @@ def print_resources_as_json(
     prop_names = OrderedDict()  # key: property name, value: None
     resource_props_list = []
     for resource in resources:
-        resource_props = dict()
+        resource_props = {}
         if show_list:
             for name in show_list:
                 if additions and name in additions:
@@ -920,8 +922,7 @@ def part_console(session, part, refresh, logger):
                 if topic_dict['topic-type'] != 'os-message-notification':
                     continue
                 obj_uri = topic_dict['object-uri']
-                if obj_uri == part.uri \
-                        or '/api/partitions/' + obj_uri == part.uri:
+                if part.uri in (obj_uri, '/api/partitions/' + obj_uri):
                     topic = topic_dict['topic-name']
                     console_log(logger, prefix,
                                 "Using existing notification topic: %s "
